@@ -1,9 +1,10 @@
 package PerlIO::code;
 
-use warnings;
+use 5.008_001;
+
 use strict;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -13,11 +14,11 @@ __END__
 
 =head1 NAME
 
-PerlIO::code - Makes a simple I/O filter
+PerlIO::code - Calls a subroutine with I/O interface
 
 =head1 VERSION
 
-This document describes PerlIO::code version 0.02
+This document describes PerlIO::code version 0.03
 
 =head1 SYNOPSIS
 
@@ -31,10 +32,20 @@ This document describes PerlIO::code version 0.02
 	open my $out, '>', sub{ print uc shift };
 	print $out while <>;
 
+	# it accepts an extra argument
+	sub my_readline{
+		my($fh) = @_;
+		my $line = <$fh>;
+		# ...filterling...
+		return $line;
+	}
+	open my $fh, '<', \&my_readline, \*STDIN;
+
 =head1 DESCRIPTION
 
-C<PerlIO::code> helps to make an I/O filter. It is easier than C<tie>, but
-provides very limited functions. All it can do is to do C<readline> and C<print>.
+C<PerlIO::code> helps to make an simple I/O filter. It is easier than C<tie>,
+but provides very limited functions. All it can do is to do C<readline()>
+and C<print()>.
 
 =head1 NOTES
 
@@ -51,7 +62,8 @@ C<PerlIO::code> is slower than the C<tie> interface.
 =item *
 
 C<< open my $in, '<', sub{ "foo" }; my $s = <$in>; >> makes an endless loop, because
-the internal C<readline> routine reads C<$in> on until reaching C<EOF>.
+the internal C<readline> routine reads C<$in> on until reaching C<EOF>, which
+is never reached.
 
 =back
 
@@ -73,6 +85,8 @@ L<http://rt.cpan.org/>.
 
 =head1 SEE ALSO
 
+L<PerlIO::Util>.
+
 L<Tie::Handle>.
 
 L<PerlIO::via>.
@@ -81,11 +95,11 @@ L<PerlIO>.
 
 =head1 AUTHOR
 
-Goro Fuji C<< <gfuji (at) cpan.org> >>
+Goro Fuji E<lt>gfuji(at)cpan.orgE<gt>.
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2008, Goro Fuji C<< <gfuji (at) cpan.org> >>. Some rights reserved.
+Copyright (c) 2008, Goro Fuji E<lt>gfuji(at)cpan.orgE<gt>. Some rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
